#
# spec file for package lua-luadbi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define flavor lua53
%define mod_name luadbi
Version:        0.7.3
Release:        1.2
Summary:        A database interface library for Lua
License:        MIT
Group:          Productivity/Databases/Tools
URL:            https://github.com/mwild1/luadbi
Source0:        https://github.com/mwild1/%{mod_name}/archive/refs/tags/v%{version}.tar.gz#/%{mod_name}-%{version}.tar.gz
# Formely found on code.google.com
Source1:        luadbi-%{version}.tar.gz
Source50:       tests-modules-load.lua
# PATCH-FIX-UPSTREAM marguerite@opensuse.org - fix postgresql headers' path
Patch0:         luadbi-postgresql-headers.patch
BuildRequires:  %{flavor}-devel
BuildRequires:  libmysqld-devel
BuildRequires:  postgresql-devel
BuildRequires:  postgresql-server-devel
BuildRequires:  sqlite3-devel
Requires:       %{flavor}
# %%lua_provides
%if "%{flavor}" == ""
Name:           lua-%{mod_name}
ExclusiveArch:  do_not_build
%else
Name:           %{flavor}-%{mod_name}
%endif

%description
LuaDBI is a database interface library for Lua. It is designed to provide a
RDBMS agnostic API for handling database operations. LuaDBI also provides
support for prepared statement handles, placeholders and bind parameters for
all database operations.

Currently LuaDBI supports DB2, Oracle, MySQL, PostgreSQL and SQLite databases
with native database drivers. But openSUSE version doesn't build with DB2 and
Oracle.

%prep
%autosetup -p1 -n luadbi-%{version}

sed -i \
    -e 's:-g -pedantic -Wall -O2:%{optflags} -fPIC -I%{lua_incdir}:g' \
    Makefile

%build
%make_build LIBDIR=%{_libdir}

%install
install -d %{buildroot}%{lua_archdir}
install -d %{buildroot}%{lua_noarchdir}
make install_free DESTDIR=%{buildroot} LUA_LDIR=%{lua_noarchdir} LUA_CDIR=%{lua_archdir}

%check
# run tests
lua%{lua_version} %{SOURCE50} %{buildroot}

%files
%license COPYING
%doc README.md
%dir %{lua_archdir}/dbd
%{lua_archdir}/dbd/*.so
%{lua_noarchdir}/*.lua

%changelog
* Thu Oct  3 2024 Matej Cepl <mcepl@cepl.eu>
- Update to 0.7.3:
  - oracle column name bugfix
  - [travis] fix mysql grant error
  - Don't break SQLite 3.6.20 as shipped in RHEL/CentOS 6
  - dbd/mysql/statement.c: fix compilation with mysql-8
  - Issue 56: Remove useless setting of is_null
  - Issue-66: dbd/mysql/statement.c: return nil for NULL
  - Attempt to provide partial fix for Issue #64.
* Thu Feb 22 2024 Michael Vetter <mvetter@suse.com>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Thu Feb 18 2021 Callum Farmer <gmbr3@opensuse.org>
- Use %%lua_provides macro for default lua versioning
* Fri Oct  9 2020 Emil Biserov <biserov@gmail.com>
- updated for 0.7.2
- tests-modules-load.lua added
* Mon Jul  6 2020 Matej Cepl <mcepl@suse.com>
- Add lua54 as new build target
* Wed Jun 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Fix build after the postgresql package gained two devel packages
* Mon Oct 30 2017 jmatejek@suse.com
- do not build for Lua 5.2
* Thu Jul 13 2017 tchvatal@suse.com
- Switch to multibuild layout to compile for all lua variants
* Sat Jun 29 2013 i@marguerite.su
- initial version 0.5
- add new patch: luadbi-postgresql-headers.patch
